<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns:datacite="http://datacite.org/schema/kernel-3" 
		xmlns:xhtml="http://www.w3.org/1999/xhtml">

 	<xsl:output method="html" encoding="UTF-8" indent="yes" /> 

	<xsl:param name="pid"/>
	
	<xsl:template match="/">
		<div id="datacite-metadata" class="datacite-font-family datacite-table">
				<xsl:for-each select="//*[local-name()='resource']">
					<xsl:call-template name="dataciteTable"/>
				</xsl:for-each>
		</div>
	</xsl:template>
	
		
    <xsl:template name="dataciteTable">
      	<div class="datacite-table">
			<xsl:call-template name="dataOneId" />
      		<xsl:call-template name="citation" />
			<xsl:call-template name="title" />
			<xsl:call-template name="creators" />
			<xsl:call-template name="contributors" />
			<xsl:call-template name="collectedDates" />
			<xsl:call-template name="createdDate" />
			<xsl:call-template name="availableDate" />
			<xsl:call-template name="abstract" />
			<xsl:call-template name="methods" />
			<xsl:call-template name="otherDescriptions" />
			<xsl:call-template name="seriesDescriptions" />
			<xsl:call-template name="site" />
			<xsl:call-template name="geoPoint" />
			<xsl:call-template name="geoBox" />
			<xsl:call-template name="subjects" />
			<xsl:call-template name="related" />
			<xsl:call-template name="publisher" />
			<xsl:call-template name="pubYear" />
			<xsl:call-template name="resourceType" />
			<xsl:call-template name="size" />
			<xsl:call-template name="format" />
			<xsl:call-template name="language" />
			<xsl:call-template name="rights" />
      	</div>
   </xsl:template>
   
   <xsl:template name="dataOneId">
   		<div class="datacite-identifier-text datacite-row">
			<div class="datacite-label">Document Identifier:</div>
			<div class="datacite-data">
				<xsl:value-of select="$pid" disable-output-escaping="yes"/>
			</div>
		</div>
   </xsl:template>
   
   <xsl:template name="title">
   		<xsl:if test="(/datacite:resource/datacite:titles/datacite:title[1])[1][normalize-space(.) != '']">
   			<div class="dc-row">
		   		<div class="dc-label">Title:</div>
   				<div class="dc-data">
   					<xsl:value-of select="(/datacite:resource/datacite:titles/datacite:title[1]/text())[1]" />
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>
   
	<xsl:template name="publisher">
   		<xsl:if test="(/datacite:resource/datacite:publisher[1])[1][normalize-space(.) != '']">
   			<div class="dc-row">
		   		<div class="dc-label">Title:</div>
   				<div class="dc-data">
   					<xsl:value-of select="(/datacite:resource/datacite:publisher[1]/text())[1]" />
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>
   
   <xsl:template name="pubYear">
   		<xsl:if test="(/datacite:resource/datacite:publicationYear[1]/text())[1]">
		   	<div class="dc-row">
	    		<div class="dc-label">Year Published:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="(/datacite:resource/datacite:publicationYear[1]/text())[1]" />
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>   
   
   <xsl:template name="collectedDates">
   		<xsl:if test="(/datacite:resource/datacite:dates/datacite:date[@dateType='Collected'][1])[1]">
		   	<div class="dc-row">
	    		<div class="dc-label">Collected Dates:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="(/datacite:resource/datacite:dates/datacite:date[@dateType='Collected'][1]/text())[1]" />
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="createdDate">
   		<xsl:if test="(/datacite:resource/datacite:dates/datacite:date[@dateType='Created'][1])[1]">
		   	<div class="dc-row">
	    		<div class="dc-label">Created Dates:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="(/datacite:resource/datacite:dates/datacite:date[@dateType='Created'][1]/text())[1]" />
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template> 
   
   <xsl:template name="availableDate">
   		<xsl:if test="(/datacite:resource/datacite:dates/datacite:date[@dateType='Available'][1])[1]">
		   	<div class="dc-row">
	    		<div class="dc-label">Available Dates:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="(/datacite:resource/datacite:dates/datacite:date[@dateType='Available'][1]/text())[1]" />
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template> 
   
   <xsl:template name="creators">
   		<xsl:if test="/datacite:resource/datacite:creators/datacite:creator/datacite:creatorName">
	   		<div class="dc-row">
		   		<div class="dc-label">Creators:</div>
		   		<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:creators/datacite:creator/datacite:creatorName">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
   <xsl:template name="contributors">
   		<xsl:if test="/datacite:resource/datacite:contributors/datacite:contributor/datacite:contributorName">
	   		<div class="dc-row">
		   		<div class="dc-label">Contributors:</div>
		   		<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:contributors/datacite:contributor">
							<li><xsl:value-of select="datacite:contributorName/text()" /> (<xsl:value-of select="../datacite:contributor/@contributorType" />)</li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
   <xsl:template name="site">
   		<xsl:if test="/datacite:resource/datacite:geoLocations/datacite:geoLocation/datacite:geoLocationPlace">
   			<div class="dc-row">
		   		<div class="dc-label">Site:</div>
   				<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:geoLocations/datacite:geoLocation/datacite:geoLocationPlace">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>

   <xsl:template name="geoPoint">
   		<xsl:if test="/datacite:resource/datacite:geoLocations/datacite:geoLocation/datacite:geoLocationPoint">
   			<div class="dc-row">
		   		<div class="dc-label">Location Point:</div>
   				<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:geoLocations/datacite:geoLocation/datacite:geoLocationPoint">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>
   
   <xsl:template name="geoBox">
   		<xsl:if test="/datacite:resource/datacite:geoLocations/datacite:geoLocation/datacite:geoLocationBox">
   			<div class="dc-row">
		   		<div class="dc-label">Location Bounding Box:</div>
   				<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:geoLocations/datacite:geoLocation/datacite:geoLocationBox">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>
   
   <xsl:template name="abstract">
   		<xsl:if test="/datacite:resource/datacite:descriptions/datacite:description[@descriptionType='Abstract']">
   			<div class="dc-row">
		   		<div class="dc-label">Abstract:</div>
   				<div class="dc-data">
   					<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:descriptions/datacite:description[@descriptionType='Abstract']">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>

   <xsl:template name="methods">
   		<xsl:if test="/datacite:resource/datacite:descriptions/datacite:description[@descriptionType='Methods']">
   			<div class="dc-row">
		   		<div class="dc-label">Methods:</div>
   				<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:descriptions/datacite:description[@descriptionType='Methods']">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template> 
   
	<xsl:template name="otherDescriptions">
   		<xsl:if test="/datacite:resource/datacite:descriptions/datacite:description[@descriptionType='Other']">
   			<div class="dc-row">
		   		<div class="dc-label">Other Descriptions:</div>
   				<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:descriptions/datacite:description[@descriptionType='Other']">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>
   
	<xsl:template name="seriesDescriptions">
   		<xsl:if test="/datacite:resource/datacite:descriptions/datacite:description[@descriptionType='SeriesInformation']">
   			<div class="dc-row">
		   		<div class="dc-label">Other Information:</div>
   				<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:descriptions/datacite:description[@descriptionType='SeriesInformation']">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>  

   <xsl:template name="rights">
   		<xsl:if test="/datacite:resource/datacite:rightsList/datacite:rights">
   			<div class="dc-row">
		   		<div class="dc-label">Rights:</div>
   				<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:rightsList/datacite:rights">
							<li><xsl:value-of select="." /> (<xsl:value-of select="./@rightsURI" />)</li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>
   
	<xsl:template name="subjects">
   		<xsl:if test="/datacite:resource/datacite:subjects/datacite:subject">
   			<div class="dc-row">
		   		<div class="dc-label">Subjects:</div>
   				<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:subjects/datacite:subject">
							<li><xsl:value-of select="." /> (<xsl:value-of select="./@subjectScheme" /><xsl:text>&#xA0;</xsl:text><xsl:value-of select="./@schemeURI" />)</li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>
   
   	<xsl:template name="related">
   		<xsl:if test="/datacite:resource/datacite:relatedIdentifiers/datacite:relatedIdentifier">
   			<div class="dc-row">
		   		<div class="dc-label">Related Documents:</div>
   				<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:relatedIdentifiers/datacite:relatedIdentifier">
							<li><xsl:value-of select="./@relationType" /><xsl:text>&#xA0;</xsl:text><xsl:value-of select="." /><xsl:text>&#xA0;</xsl:text>(<xsl:value-of select="./@relatedIdentifierType" />)</li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>

   <xsl:template name="resourceType">
   		<xsl:if test="/datacite:resource/datacite:resourceType">
		   	<div class="dc-row">
	    		<div class="dc-label">Resource Type:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="/datacite:resource/datacite:resourceType/text()" /><xsl:text>&#xA0;</xsl:text><xsl:value-of select="/datacite:resource/datacite:resourceType/@resourceTypeGeneral" />
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>   

   <xsl:template name="language">
   		<xsl:if test="/datacite:resource/datacite:language">
		   	<div class="dc-row">
	    		<div class="dc-label">Language:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="/datacite:resource/datacite:language/text()" />
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>

   <xsl:template name="size">
   		<xsl:if test="/datacite:resource/datacite:sizes/datacite:size">
   			<div class="dc-row">
		   		<div class="dc-label">Size:</div>
   				<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:sizes/datacite:size">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>
   
 	<xsl:template name="format">
   		<xsl:if test="/datacite:resource/datacite:formats/datacite:format">
   			<div class="dc-row">
		   		<div class="dc-label">Format:</div>
   				<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="/datacite:resource/datacite:formats/datacite:format">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>

   <xsl:template name="citation">
  		<div class="dc-row">
  			<div class="dc-label">Data Set Citation:</div>
  			<div class="dc-data">
				<xsl:for-each select="/datacite:resource/datacite:creators/datacite:creator/datacite:creatorName">
			   		<xsl:value-of select="substring-before(string(.),',')" />
			   		<xsl:text>, </xsl:text>
			   		<xsl:value-of select="substring(substring-after(string(.),', '),1,1)" />
			   		<xsl:text>. </xsl:text>
				</xsl:for-each>
				<xsl:value-of select="(/datacite:resource/datacite:publicationYear[1]/text())[1]" />
				<xsl:text>. </xsl:text>
				<xsl:value-of select="(/datacite:resource/datacite:titles/datacite:title[1]/text())[1]" />
				<xsl:text> </xsl:text>
				<xsl:value-of select="$pid" disable-output-escaping="yes"/>
			</div>
		</div>
   </xsl:template>
   
   <xsl:template name="formatDate">
		<xsl:param name="dateTime" />
		<xsl:if test="contains($dateTime,'T')">
			<xsl:variable name="date" select="substring-before($dateTime, 'T')" />
			<xsl:variable name="year" select="substring-before($date, '-')" />
			<xsl:variable name="month" select="substring-before(substring-after($date, '-'), '-')" />
			<xsl:variable name="day" select="substring-after(substring-after($date, '-'), '-')" />
			<xsl:value-of select="concat($month, '-', $day, '-', $year)" />
		</xsl:if>
		<xsl:if test="not(contains($dateTime,'T'))">
			<xsl:variable name="year" select="substring-before($dateTime, '-')" />
			<xsl:variable name="month" select="substring-before(substring-after($dateTime, '-'), '-')" />
			<xsl:variable name="day" select="substring-after(substring-after($dateTime, '-'), '-')" />
			<xsl:value-of select="concat($month, '-', $day, '-', $year)" />
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="formatTime">
		<xsl:param name="dateTime" />
		<xsl:value-of select="substring-after($dateTime, 'T')" />
	</xsl:template>
	   
</xsl:stylesheet>