<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns:dwc="http://rs.tdwg.org/dwc/terms/" 
		xmlns:dcterms="http://purl.org/dc/terms/" 
		xmlns:bibo="http://purl.org/ontology/bibo/" >

 	<xsl:output method="html" encoding="UTF-8" indent="yes" /> 

	<xsl:param name="pid"/>
	
	<xsl:template match="/">
		<div id="dryad-metadata" class="dryad-font-family dyrad-table">
				<xsl:for-each select="*[local-name()='DryadDataPackage']">
					<xsl:call-template name="dryadDataPackage"/>
				</xsl:for-each>
				<xsl:for-each select="*[local-name()='DryadDataFile']">
					<xsl:call-template name="dryadDataFile"/>
				</xsl:for-each>
		</div>
	</xsl:template>
	
    <xsl:template name="dryadDataPackage">
      	<div class="dryad-data-package">
      		<xsl:call-template name="citation" />
			<xsl:call-template name="dataOneId" />
			<xsl:call-template name="title" />
			<xsl:call-template name="submittedDate" />
			<xsl:call-template name="availableDate" />
			<xsl:call-template name="authors" />
			<xsl:call-template name="abstract" />
			<xsl:call-template name="keywords" />
			<xsl:call-template name="scientificNames" />
			<xsl:call-template name="spatial" />
			<xsl:call-template name="temporal" />
			<xsl:call-template name="journal" />
			<xsl:call-template name="references" />
			<xsl:call-template name="provenance" />
			<xsl:call-template name="dataRights" />
			<xsl:call-template name="hasPart" />
      	</div>
   </xsl:template>
   
    <xsl:template name="dryadDataFile">
		<table class="dryad-data-file">
      		<xsl:call-template name="citation" />
   			<xsl:call-template name="dataOneId" />
	      	<xsl:call-template name="title"/>
	      	<xsl:call-template name="submittedDate" />
	      	<xsl:call-template name="availableDate" />
			<xsl:call-template name="authors" />
			<xsl:call-template name="description" />
			<xsl:call-template name="keywords" />
			<xsl:call-template name="scientificNames" />
			<xsl:call-template name="spatial" />
			<xsl:call-template name="temporal" />
			<xsl:call-template name="provenance" />
			<xsl:call-template name="dataRights" />
			<xsl:call-template name="partOf" />
      </table>
   </xsl:template>
   
   <xsl:template name="dataOneId">
   		<div class="dryad-identifier-text dryad-row">
			<div class="dryad-label">Document Identifier:</div>
			<div class="dryad-data">
				<xsl:value-of select="$pid" disable-output-escaping="yes"/>
			</div>
		</div>
   </xsl:template>
   
   <xsl:template name="title">
   		<xsl:if test="dcterms:title">
   			<div class="dryad-row">
		   		<div class="dryad-label">Title:</div>
   				<div class="dryad-data">
			   		<xsl:value-of select="dcterms:title" />
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>
   
   <xsl:template name="authors">
   		<xsl:if test="dcterms:creator">
	   		<div class="dryad-row">
		   		<div class="dryad-label">Authors:</div>
		   		<div class="dryad-data">
			   		<ul class="dryad-data-list">
						<xsl:for-each select="dcterms:creator">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
   <xsl:template name="submittedDate">
   		<xsl:if test="dcterms:dateSubmitted">
		   	<div class="dryad-row">
	    		<div class="dryad-label">Date Submitted:</div>
	   			<div class="dryad-data">
	   				<xsl:call-template name="formatDate">
						<xsl:with-param name="dateTime" select="dcterms:dateSubmitted" />
					</xsl:call-template>
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="abstract">
   		<xsl:if test="dcterms:description">
	   		<div class="dryad-row">
		   		<div class="dryad-label">Abstract:</div>
	   			<div class="dryad-data">
	   				<xsl:value-of select="dcterms:description" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>

   <xsl:template name="description">
   		<xsl:if test="dcterms:description">
	   		<div class="dryad-row">
		   		<div class="dryad-label">Description:</div>
	   			<div class="dryad-data">
	   				<xsl:value-of select="dcterms:description" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="keywords">
   		<xsl:if test="dcterms:subject">
	   		<div class="dryad-row">
				<div class="dryad-label">Keywords:</div>
				<div class="dryad-data">
					<ul class="dryad-data-list">
						<xsl:for-each select="dcterms:subject">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div> 
		</xsl:if>
   </xsl:template>

   <xsl:template name="scientificNames">
   		<xsl:if test="dwc:scientificName">
	   		<div class="dryad-row">
				<div class="dryad-label">Scientific Names:</div>
				<div class="dryad-data">
					<ul class="dryad-data-list">
						<xsl:for-each select="dwc:scientificName">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div> 
		</xsl:if>
   </xsl:template>
 
   <xsl:template name="spatial">
   		<xsl:if test="dcterms:spatial">
	   		<div class="dryad-row">
	   			<div class="dryad-label">Spatial:</div>
	   			<div class="dryad-data">
		   			<ul class="dryad-data-list">
	   					<xsl:for-each select="dcterms:spatial">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="temporal">
   		<xsl:if test="dcterms:temporal">
	   		<div class="dryad-row">
	   			<div class="dryad-label">Temporal:</div>
	   			<div class="dryad-data">
		   			<ul class="dryad-data-list">
	   					<xsl:for-each select="dcterms:temporal">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
	<xsl:template name="journal">
		<xsl:if test="bibo:Journal">
	   		<div class="dryad-row">
	   			<div class="dryad-label">Journal:</div>
	   			<div class="dryad-data">
	   				<xsl:value-of select="bibo:Journal" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
 	<xsl:template name="references">
 		<xsl:if test="dcterms:references">
	   		<div class="dryad-row">
	   			<div class="dryad-label">References:</div>
	   			<div class="dryad-data">
		   			<ul class="dryad-data-list">
	   					<xsl:for-each select="dcterms:references">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="provenance">
   		<xsl:if test="dcterms:provenance">
	   		<div class="dryad-row">
	   			<div class="dryad-label">Provenance:</div>
	   			<div class="dryad-data">
	   				<xsl:value-of select="dcterms:provenance" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
	<xsl:template name="availableDate">
		<xsl:if test="dcterms:available">
		   	<div class="dryad-row">
	    		<div class="dryad-label">Date Available:</div>
	   			<div class="dryad-data">
	   			   	<xsl:call-template name="formatDate">
						<xsl:with-param name="dateTime" select="dcterms:available" />
					</xsl:call-template>
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>
   
	<xsl:template name="dataRights">
		<xsl:if test="dcterms:rights">
		   	<div class="dryad-row">
	    		<div class="dryad-label">Rights:</div>
	   			<div class="dryad-data">
	   				<xsl:value-of select="dcterms:rights" />
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="partOf">
   		<xsl:if test="dcterms:isPartOf">
	   		<div class="dryad-row">
				<div class="dryad-label">Part of:</div>
				<div class="dryad-data">
					<ul class="dryad-data-list">
						<xsl:for-each select="dcterms:isPartOf">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
   <xsl:template name="hasPart">
   		<xsl:if test="dcterms:hasPart">
	   		<div class="dryad-row">
				<div class="dryad-label">Has Part:</div>
				<div class="dryad-data">
					<ul class="dryad-data-list">
						<xsl:for-each select="dcterms:hasPart">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
   <xsl:template name="citation">
  		<div class="dryad-row">
  			<div class="dryad-label">Data Set Citation:</div>
  			<div class="dryad-data">
				<xsl:for-each select="dcterms:creator">
			   		<xsl:value-of select="substring-before(string(.),',')" />
			   		<xsl:text>, </xsl:text>
			   		<xsl:value-of select="substring(substring-after(string(.),', '),1,1)" />
			   		<xsl:text>. </xsl:text>
				</xsl:for-each>
				<xsl:call-template name="formatDate">
					<xsl:with-param name="dateTime" select="dcterms:available" />
				</xsl:call-template>
				<xsl:text>. </xsl:text>
				<xsl:value-of select="dcterms:title" />
				<xsl:text> </xsl:text>
				<xsl:value-of select="$pid" disable-output-escaping="yes"/>
			</div>
		</div>
   </xsl:template>
   
   <xsl:template name="formatDate">
		<xsl:param name="dateTime" />
		<xsl:variable name="date" select="substring-before($dateTime, 'T')" />
		<xsl:variable name="year" select="substring-before($date, '-')" />
		<xsl:variable name="month" select="substring-before(substring-after($date, '-'), '-')" />
		<xsl:variable name="day" select="substring-after(substring-after($date, '-'), '-')" />
		<xsl:value-of select="concat($month, '-', $day, '-', $year)" />
	</xsl:template>
	
	<xsl:template name="formatTime">
		<xsl:param name="dateTime" />
		<xsl:value-of select="substring-after($dateTime, 'T')" />
	</xsl:template>
        
</xsl:stylesheet>