<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns:dc="http://purl.org/dc/elements/1.1/"  
		xmlns:dcterms="http://purl.org/dc/terms/">

 	<xsl:output method="html" encoding="UTF-8" indent="yes" /> 

	<xsl:param name="pid"/>
	
	<xsl:template match="/">
		<div id="qdc-metadata" class="qdc-font-family qdc-table">
				<xsl:for-each select="*[local-name()='qualifieddc']">
					<xsl:call-template name="qualifieddc"/>
				</xsl:for-each>
		</div>
	</xsl:template>
	
    <xsl:template name="qualifieddc">
      	<div class="qualified-dc-table">
      		<xsl:call-template name="citation" />
			<xsl:call-template name="dataOneId" />
			<xsl:call-template name="title" />
			<xsl:call-template name="alternativeTitle" />
			<xsl:call-template name="submittedDate" />
			<xsl:call-template name="availableDate" />
			<xsl:call-template name="dateAccepted" />
			<xsl:call-template name="dateCopyrighted" />
			<xsl:call-template name="issued" />
			<xsl:call-template name="created" />
			<xsl:call-template name="modified" />
			<xsl:call-template name="valid" />
			<xsl:call-template name="authors" />
 			<xsl:call-template name="contributors" />
			<xsl:call-template name="abstract" />
			<xsl:call-template name="description" />
			<xsl:call-template name="keywords" />
			<xsl:call-template name="coverage" />
			<xsl:call-template name="spatial" />
			<xsl:call-template name="temporal" />
			<xsl:call-template name="tableOfContents" />
			<xsl:call-template name="type" />
			<xsl:call-template name="format" />
			<xsl:call-template name="medium" />
			<xsl:call-template name="extent" />
			<xsl:call-template name="conformsTo" />
			<xsl:call-template name="language" />
			<xsl:call-template name="bibliographicCitation" />
			<xsl:call-template name="publisher" />
			<xsl:call-template name="sources"/>
			<xsl:call-template name="provenance" />
			<xsl:call-template name="accrualMethod" />
			<xsl:call-template name="accrualPeriodicity" />
			<xsl:call-template name="accrualPolicy" />
			<xsl:call-template name="audience" />
			<xsl:call-template name="educationLevel" />
			<xsl:call-template name="instructionalMethod" />
			<xsl:call-template name="relations" />
			<xsl:call-template name="references" />
			<xsl:call-template name="isReferencedBy" />
			<xsl:call-template name="hasPart" />
			<xsl:call-template name="partOf" />
			<xsl:call-template name="hasVersion" />
			<xsl:call-template name="isVersionOf" />
			<xsl:call-template name="hasFormat" />
			<xsl:call-template name="isFormatOf" />
			<xsl:call-template name="replaces" />
			<xsl:call-template name="isReplacedBy" />
			<xsl:call-template name="requires" />
			<xsl:call-template name="isRequiredBy" />
			<xsl:call-template name="mediator" />
			<xsl:call-template name="rightsHolder" />
			<xsl:call-template name="dataRights" />
			<xsl:call-template name="accessRights" />
			<xsl:call-template name="license" />
      	</div>
   </xsl:template>

   <xsl:template name="dataOneId">
   		<div class="dc-identifier-text dc-row">
			<div class="dc-label">Document Identifier:</div>
			<div class="dc-data">
				<xsl:value-of select="$pid" disable-output-escaping="yes"/>
			</div>
		</div>
   </xsl:template>
   
   <xsl:template name="title">
   		<xsl:if test="dc:title or dcterms:title">
   			<div class="dc-row">
		   		<div class="dc-label">Title:</div>
   				<div class="dc-data">
   					<xsl:value-of select="dc:title" />
			   		<xsl:value-of select="dcterms:title" />
	   		    </div>
	   		</div>
	   	</xsl:if>
   </xsl:template>
   
   <xsl:template name="authors">
   		<xsl:if test="dc:creator or dcterms:creator">
	   		<div class="dc-row">
		   		<div class="dc-label">Authors:</div>
		   		<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="dc:creator">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
						<xsl:for-each select="dcterms:creator">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
	<xsl:template name="contributors">
   		<xsl:if test="dc:contributor or dcterms:contributor">
	   		<div class="dc-row">
		   		<div class="dc-label">Contributors:</div>
		   		<div class="dc-data">
			   		<ul class="dc-data-list">
						<xsl:for-each select="dc:contributor">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
						<xsl:for-each select="dcterms:contributor">
							<li><xsl:value-of select="." /></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
   <xsl:template name="submittedDate">
   		<xsl:if test="dcterms:dateSubmitted">
		   	<div class="dc-row">
	    		<div class="dc-label">Date Submitted:</div>
	   			<div class="dc-data">
	   				<xsl:call-template name="formatDate">
						<xsl:with-param name="dateTime" select="dcterms:dateSubmitted" />
					</xsl:call-template>
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="dateAccepted">
   		<xsl:if test="dcterms:dateAccepted">
		   	<div class="dc-row">
	    		<div class="dc-label">Date Accepted:</div>
	   			<div class="dc-data">
	   				<xsl:call-template name="formatDate">
						<xsl:with-param name="dateTime" select="dcterms:dateAccepted" />
					</xsl:call-template>
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="dateCopyrighted">
   		<xsl:if test="dcterms:dateCopyrighted">
		   	<div class="dc-row">
	    		<div class="dc-label">Date Copyrighted:</div>
	   			<div class="dc-data">
	   				<xsl:call-template name="formatDate">
						<xsl:with-param name="dateTime" select="dcterms:dateCopyrighted" />
					</xsl:call-template>
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="issued">
   		<xsl:if test="dcterms:issued">
		   	<div class="dc-row">
	    		<div class="dc-label">Date Issued:</div>
	   			<div class="dc-data">
	   				<xsl:call-template name="formatDate">
						<xsl:with-param name="dateTime" select="dcterms:issued" />
					</xsl:call-template>
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>   
   
   <xsl:template name="created">
   		<xsl:if test="dcterms:created">
		   	<div class="dc-row">
	    		<div class="dc-label">Date Created:</div>
	   			<div class="dc-data">
	   				<xsl:call-template name="formatDate">
						<xsl:with-param name="dateTime" select="dcterms:created" />
					</xsl:call-template>
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>   
   
   <xsl:template name="modified">
   		<xsl:if test="dcterms:modified">
		   	<div class="dc-row">
	    		<div class="dc-label">Date Modified:</div>
	   			<div class="dc-data">
	   				<xsl:call-template name="formatDate">
						<xsl:with-param name="dateTime" select="dcterms:modified" />
					</xsl:call-template>
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>   
   
   <xsl:template name="valid">
   		<xsl:if test="dcterms:valid">
		   	<div class="dc-row">
	    		<div class="dc-label">Date Valid:</div>
	   			<div class="dc-data">
					<xsl:value-of select="dcterms:valid" />
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>
         
   <xsl:template name="abstract">
   		<xsl:if test="dcterms:abstract">
	   		<div class="dc-row">
		   		<div class="dc-label">Abstract:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:abstract" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="accessRights">
   		<xsl:if test="dcterms:accessRights">
	   		<div class="dc-row">
		   		<div class="dc-label">Access Rights:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:accessRights" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="audience">
   		<xsl:if test="dcterms:audience">
	   		<div class="dc-row">
		   		<div class="dc-label">Audience:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:audience" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="bibliographicCitation">
   		<xsl:if test="dcterms:bibliographicCitation">
	   		<div class="dc-row">
		   		<div class="dc-label">Bibliographic Citation:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:bibliographicCitation" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>   
   
	<xsl:template name="alternativeTitle">
   		<xsl:if test="dcterms:alternative">
	   		<div class="dc-row">
		   		<div class="dc-label">Alternative Title:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:alternative" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
  	<xsl:template name="accrualMethod">
   		<xsl:if test="dcterms:accrualMethod">
	   		<div class="dc-row">
	   			<div class="dc-label">Accrual Method:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dcterms:accrualMethod">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>

  	<xsl:template name="accrualPeriodicity">
   		<xsl:if test="dcterms:accrualPeriodicity">
	   		<div class="dc-row">
	   			<div class="dc-label">Accrual Periodicity:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dcterms:accrualPeriodicity">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
  	<xsl:template name="accrualPolicy">
   		<xsl:if test="dcterms:accrualPolicy">
	   		<div class="dc-row">
	   			<div class="dc-label">Accrual Policy:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dcterms:accrualPolicy">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>   


   <xsl:template name="description">
   		<xsl:if test="dc:descripiton or dcterms:description">
	   		<div class="dc-row">
		   		<div class="dc-label">Description:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dc:description" />
	   				<xsl:value-of select="dcterms:description" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="keywords">
   		<xsl:if test="dc:subject or dcterms:subject">
	   		<div class="dc-row">
				<div class="dc-label">Keywords:</div>
				<div class="dc-data">
					<ul class="dc-data-list">
						<xsl:for-each select="dc:subject">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
						<xsl:for-each select="dcterms:subject">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>

   <xsl:template name="coverage">
   		<xsl:if test="dc:coverage or dcterms:coverage">
	   		<div class="dc-row">
	   			<div class="dc-label">Coverage:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dc:coverage">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   					<xsl:for-each select="dcterms:coverage">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
 
   <xsl:template name="spatial">
   		<xsl:if test="dcterms:spatial">
	   		<div class="dc-row">
	   			<div class="dc-label">Spatial:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dcterms:spatial">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="temporal">
   		<xsl:if test="dcterms:temporal">
	   		<div class="dc-row">
	   			<div class="dc-label">Temporal:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dcterms:temporal">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
	<xsl:template name="format">
 		<xsl:if test="dc:format or dcterms:format">
	   		<div class="dc-row">
	   			<div class="dc-label">Format:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dc:format">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   					<xsl:for-each select="dcterms:format">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>

   <xsl:template name="medium">
   		<xsl:if test="dcterms:medium">
	   		<div class="dc-row">
		   		<div class="dc-label">Medium:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:medium" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="extent">
   		<xsl:if test="dcterms:extent">
	   		<div class="dc-row">
		   		<div class="dc-label">Extent:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:extent" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>

   <xsl:template name="conformsTo">
   		<xsl:if test="dcterms:conformsTo">
	   		<div class="dc-row">
		   		<div class="dc-label">Conforms To:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:conformsTo" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
	<xsl:template name="language">
 		<xsl:if test="dc:language or dcterms:language">
	   		<div class="dc-row">
	   			<div class="dc-label">Language:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dc:language">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   					<xsl:for-each select="dcterms:language">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
	<xsl:template name="publisher">
 		<xsl:if test="dc:publisher or dcterms:publisher">
	   		<div class="dc-row">
	   			<div class="dc-label">Publisher:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dc:publisher">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   					<xsl:for-each select="dcterms:publisher">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>   

   <xsl:template name="tableOfContents">
   		<xsl:if test="dcterms:tableOfContents">
	   		<div class="dc-row">
		   		<div class="dc-label">Table Of Contents:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:tableOfContents" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="educationLevel">
   		<xsl:if test="dcterms:educationLevel">
	   		<div class="dc-row">
		   		<div class="dc-label">Education Level:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:educationLevel" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>   
   
   <xsl:template name="instructionalMethod">
   		<xsl:if test="dcterms:instructionalMethod">
	   		<div class="dc-row">
		   		<div class="dc-label">Instructional Method:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:instructionalMethod" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>    

 	<xsl:template name="sources">
 		<xsl:if test="dc:source or dcterms:source">
	   		<div class="dc-row">
	   			<div class="dc-label">Sources:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dc:source">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   					<xsl:for-each select="dcterms:source">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>

 	<xsl:template name="relations">
 		<xsl:if test="dc:relation or dcterms:relation">
	   		<div class="dc-row">
	   			<div class="dc-label">Relations:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dc:relation">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   					<xsl:for-each select="dcterms:relation">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
 	<xsl:template name="references">
 		<xsl:if test="dcterms:references">
	   		<div class="dc-row">
	   			<div class="dc-label">References:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dcterms:references">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>

 	<xsl:template name="isReferencedBy">
 		<xsl:if test="dcterms:isReferencedBy">
	   		<div class="dc-row">
	   			<div class="dc-label">Is Referenced By:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dcterms:isReferencedBy">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
	<xsl:template name="hasVersion">
 		<xsl:if test="dcterms:hasVersion">
	   		<div class="dc-row">
	   			<div class="dc-label">Has Version:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dcterms:hasVersion">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
	<xsl:template name="isVersionOf">
 		<xsl:if test="dcterms:isVersionOf">
	   		<div class="dc-row">
	   			<div class="dc-label">Is Version Of:</div>
	   			<div class="dc-data">
		   			<ul class="dc-data-list">
	   					<xsl:for-each select="dcterms:isVersionOf">
		   					<li><xsl:value-of select="." /></li>
	   					</xsl:for-each>
	   				</ul>
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>   
   
   <xsl:template name="provenance">
   		<xsl:if test="dcterms:provenance">
	   		<div class="dc-row">
	   			<div class="dc-label">Provenance:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:provenance" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
	<xsl:template name="type">
   		<xsl:if test="dc:type or dcterms:type">
	   		<div class="dc-row">
	   			<div class="dc-label">Type:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dc:type" />
	   				<xsl:value-of select="dcterms:type" />
	   			</div>
	   		</div>
   		</xsl:if>
   </xsl:template>
   
	<xsl:template name="availableDate">
		<xsl:if test="dcterms:available">
		   	<div class="dc-row">
	    		<div class="dc-label">Date Available:</div>
	   			<div class="dc-data">
	   			   	<xsl:call-template name="formatDate">
						<xsl:with-param name="dateTime" select="dcterms:available" />
					</xsl:call-template>
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>
   
	<xsl:template name="dataRights">
		<xsl:if test="dc:rights or dcterms:rights">
		   	<div class="dc-row">
	    		<div class="dc-label">Rights:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dc:rights" />
	   				<xsl:value-of select="dcterms:rights" />
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>

	<xsl:template name="license">
		<xsl:if test="dcterms:license">
		   	<div class="dc-row">
	    		<div class="dc-label">License:</div>
	   			<div class="dc-data">
	   				<xsl:value-of select="dcterms:license" />
	   			</div>  		
	   		</div>
   		</xsl:if>
   </xsl:template>
   
   <xsl:template name="hasPart">
   		<xsl:if test="dcterms:hasPart">
	   		<div class="dc-row">
				<div class="dc-label">Has Part:</div>
				<div class="dc-data">
					<ul class="dc-data-list">
						<xsl:for-each select="dcterms:hasPart">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
   <xsl:template name="partOf">
   		<xsl:if test="dcterms:isPartOf">
	   		<div class="dc-row">
				<div class="dc-label">Part of:</div>
				<div class="dc-data">
					<ul class="dc-data-list">
						<xsl:for-each select="dcterms:isPartOf">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>   

   <xsl:template name="hasFormat">
   		<xsl:if test="dcterms:hasFormat">
	   		<div class="dc-row">
				<div class="dc-label">Has Format:</div>
				<div class="dc-data">
					<ul class="dc-data-list">
						<xsl:for-each select="dcterms:hasFormat">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>  			
   
   <xsl:template name="isFormatOf">
   		<xsl:if test="dcterms:isFormatOf">
	   		<div class="dc-row">
				<div class="dc-label">Is Format Of:</div>
				<div class="dc-data">
					<ul class="dc-data-list">
						<xsl:for-each select="dcterms:isFormatOf">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   		
   <xsl:template name="replaces">
   		<xsl:if test="dcterms:replaces">
	   		<div class="dc-row">
				<div class="dc-label">Replaces:</div>
				<div class="dc-data">
					<ul class="dc-data-list">
						<xsl:for-each select="dcterms:replaces">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   		
   <xsl:template name="isReplacedBy">
   		<xsl:if test="dcterms:isReplacedBy">
	   		<div class="dc-row">
				<div class="dc-label">Is Replaced By:</div>
				<div class="dc-data">
					<ul class="dc-data-list">
						<xsl:for-each select="dcterms:isReplacedBy">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
   <xsl:template name="requires">
   		<xsl:if test="dcterms:requires">
	   		<div class="dc-row">
				<div class="dc-label">Requires:</div>
				<div class="dc-data">
					<ul class="dc-data-list">
						<xsl:for-each select="dcterms:requires">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
   <xsl:template name="isRequiredBy">
   		<xsl:if test="dcterms:isRequiredBy">
	   		<div class="dc-row">
				<div class="dc-label">Is Required By:</div>
				<div class="dc-data">
					<ul class="dc-data-list">
						<xsl:for-each select="dcterms:isRequiredBy">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
   <xsl:template name="mediator">
   		<xsl:if test="dcterms:mediator">
	   		<div class="dc-row">
				<div class="dc-label">Mediator:</div>
				<div class="dc-data">
					<ul class="dc-data-list">
						<xsl:for-each select="dcterms:mediator">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>
   
   <xsl:template name="rightsHolder">
   		<xsl:if test="dcterms:rightsHolder">
	   		<div class="dc-row">
				<div class="dc-label">Rights Holder:</div>
				<div class="dc-data">
					<ul class="dc-data-list">
						<xsl:for-each select="dcterms:rightsHolder">
							<li><xsl:value-of select="."/></li>
						</xsl:for-each>
					</ul>
				</div>
			</div>
		</xsl:if>
   </xsl:template>    

   <xsl:template name="citation">
  		<div class="dc-row">
  			<div class="dc-label">Data Set Citation:</div>
  			<div class="dc-data">
				<xsl:for-each select="dcterms:creator">
			   		<xsl:value-of select="substring-before(string(.),',')" />
			   		<xsl:text>, </xsl:text>
			   		<xsl:value-of select="substring(substring-after(string(.),', '),1,1)" />
			   		<xsl:text>. </xsl:text>
				</xsl:for-each>
				<xsl:call-template name="formatDate">
					<xsl:with-param name="dateTime" select="dcterms:available" />
				</xsl:call-template>
				<xsl:text>. </xsl:text>
				<xsl:value-of select="dcterms:title" />
				<xsl:text> </xsl:text>
				<xsl:value-of select="$pid" disable-output-escaping="yes"/>
			</div>
		</div>
   </xsl:template>
   
   <xsl:template name="formatDate">
		<xsl:param name="dateTime" />
		<xsl:if test="contains($dateTime,'T')">
			<xsl:variable name="date" select="substring-before($dateTime, 'T')" />
			<xsl:variable name="year" select="substring-before($date, '-')" />
			<xsl:variable name="month" select="substring-before(substring-after($date, '-'), '-')" />
			<xsl:variable name="day" select="substring-after(substring-after($date, '-'), '-')" />
			<xsl:value-of select="concat($month, '-', $day, '-', $year)" />
		</xsl:if>
		<xsl:if test="not(contains($dateTime,'T'))">
			<xsl:variable name="year" select="substring-before($dateTime, '-')" />
			<xsl:variable name="month" select="substring-before(substring-after($dateTime, '-'), '-')" />
			<xsl:variable name="day" select="substring-after(substring-after($dateTime, '-'), '-')" />
			<xsl:value-of select="concat($month, '-', $day, '-', $year)" />
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="formatTime">
		<xsl:param name="dateTime" />
		<xsl:value-of select="substring-after($dateTime, 'T')" />
	</xsl:template>
        
</xsl:stylesheet>